@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2017-2024 Wellington Wallace
+ *  Copyright © 2017-2025 Wellington Wallace
  *
  *  This file is part of Easy Effects.
  *
@@ -55,7 +55,9 @@ Pitch::Pitch(const std::string& tag,
   tempo_difference = g_settings_get_double(settings, "tempo-difference");
   rate_difference = g_settings_get_double(settings, "rate-difference");
 
+  cents = g_settings_get_double(settings, "cents");
   semitones = g_settings_get_double(settings, "semitones");
+  octaves = g_settings_get_double(settings, "octaves");
 
   // resetting soundtouch when bypass is pressed so its internal data is discarded
 
@@ -179,17 +181,36 @@ Pitch::Pitch(const std::string& tag,
                                           }),
                                           this));
 
-  gconnections.push_back(g_signal_connect(settings, "changed::semitones",
+  gconnections.push_back(g_signal_connect(settings, "changed::cents",
                                           G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
                                             auto* self = static_cast<Pitch*>(user_data);
-
-                                            self->semitones = g_settings_get_double(settings, key);
-
+                                            self->cents = g_settings_get_double(settings, key);
                                             if (!self->soundtouch_ready) {
                                               return;
                                             }
+                                            self->update_pitch();
+                                          }),
+                                          this));
 
-                                            self->set_semitones();
+  gconnections.push_back(g_signal_connect(settings, "changed::semitones",
+                                          G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                                            auto* self = static_cast<Pitch*>(user_data);
+                                            self->semitones = g_settings_get_double(settings, key);
+                                            if (!self->soundtouch_ready) {
+                                              return;
+                                            }
+                                            self->update_pitch();
+                                          }),
+                                          this));
+
+  gconnections.push_back(g_signal_connect(settings, "changed::octaves",
+                                          G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                                            auto* self = static_cast<Pitch*>(user_data);
+                                            self->octaves = g_settings_get_double(settings, key);
+                                            if (!self->soundtouch_ready) {
+                                              return;
+                                            }
+                                            self->update_pitch();
                                           }),
                                           this));
 
@@ -331,16 +352,6 @@ void Pitch::process(std::span<float>& left_in,
   }
 }
 
-void Pitch::set_semitones() {
-  if (snd_touch == nullptr) {
-    return;
-  }
-
-  std::scoped_lock<std::mutex> lock(data_mutex);
-
-  snd_touch->setPitchSemiTones(semitones);
-}
-
 void Pitch::set_sequence_length() {
   if (snd_touch == nullptr) {
     return;
@@ -413,13 +424,10 @@ void Pitch::set_rate_difference() {
 
 void Pitch::init_soundtouch() {
   delete snd_touch;
-
   snd_touch = new soundtouch::SoundTouch();
-
   snd_touch->setSampleRate(rate);
   snd_touch->setChannels(2);
-
-  set_semitones();
+  update_pitch();
   set_quick_seek();
   set_anti_alias();
   set_sequence_length();
@@ -432,3 +440,12 @@ void Pitch::init_soundtouch() {
 auto Pitch::get_latency_seconds() -> float {
   return latency_value;
 }
+
+void Pitch::update_pitch() {
+  if (snd_touch == nullptr) {
+    return;
+  }
+  double total_semitones = semitones + (octaves * 12.0) + (cents / 100.0);
+  std::scoped_lock<std::mutex> lock(data_mutex);
+  snd_touch->setPitchSemiTones(total_semitones);
+}
